@@ -1,22 +1,16 @@
 package Kwiki::UserName::Remote;
-use strict;
-use warnings;
-use Kwiki::UserName '-Base';
+use Kwiki::UserName -Base;
 use mixin 'Kwiki::Installer';
 
-our $VERSION = "0.01";
+our $VERSION = "0.02";
 
-const class_id => 'user_name';
 const class_title => 'Kwiki user name from HTTP authentication';
-const css_file => 'user_name.css';
 
 sub register {
     my $registry = shift;
     $registry->add(preload => 'user_name');
 }
 
-1;
-
 __DATA__
 
 =head1 NAME 
@@ -37,7 +31,7 @@ L<Kwiki>, L<Kwiki::Users::Remote>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2004 by Ian Langworth
+Copyright (C) 2004, 2005 by Ian Langworth
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
@@ -50,7 +44,6 @@ div #user_name_title {
     float: right;
 }
 __template/tt2/user_name_title.html__
-<!-- BEGIN user_name_title.html -->
 <div id="user_name_title">
 <em>(Logged in as 
 <a href="[% script_name %]?[% hub.users.current.name %]">
@@ -58,6 +51,3 @@ __template/tt2/user_name_title.html__
 </a>)
 </em>
 </div>
-<!-- END user_name_title.html -->
-
-
